@@ -260,6 +260,7 @@ class Variable(pd.Series):
         """
         Copy metadata from another Variable.
         """
+        # LOG.debug(f'Copying metadata from {other}')  # BUG: Causes infinite recursion!
         if isinstance(other, Variable):
             for name in self._metadata:
                 value = getattr(self, name, None)
@@ -403,6 +404,7 @@ class Dataset(pd.DataFrame):
         """
         Copy metadata from a Dataset or mapping of Variables.
         """
+        LOG.debug(f'Copying metadata from {other}')
         if isinstance(other, Dataset):
             for name in self._metadata:
                 object.__setattr__(self, name, getattr(other, name, None))
@@ -468,7 +470,7 @@ class Dataset(pd.DataFrame):
         self.copy_metadata(data)
         for name, value in metadata.items():
             setattr(self, name, getattr(self, name, value))
-        LOG.debug(f'Initialized {self}')
+        # LOG.debug(f'Initialized {self}')  # BUG: Causes infinite recursion!
 
     def __finalize__(self, other, method=None, **kwds):
         """
